#
# spec file for package gtk2-branding
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor openSUSE%nil
%if "%{flavor}" == ""
%define branding_name %{nil}
ExclusiveArch:  do-not-build
%else
%define branding_name %{flavor}
%define dash -
%if "%{flavor}" == "SLE"
%define build_SLE 1
%else
%define build_openSUSE 1
%endif
%if (0%{?build_SLE} && 0%{?is_opensuse}) || (0%{?build_openSUSE} && ! 0%{?is_opensuse})
# Don't build SLE branding on openSUSE and vice-versa
ExclusiveArch:  do-not-build
%endif
%endif

Name:           gtk2-branding%{?dash}%{branding_name}
Version:        15.0
Release:        2.4
URL:            http://www.gtk.org/
Summary:        The GTK+ toolkit library (version 2) -- %{branding_name} theme configuration
License:        BSD-3-Clause
Group:          System/Libraries
Source:         gtk2-branding-gtkrc
Source1:        gtk2-branding-COPYING
BuildRequires:  gtk2
%define gtk2_real_package %(rpm -q --qf '%%{name}' --whatprovides gtk2)
%define gtk2_version %(rpm -q --qf '%%{version}' %{gtk2_real_package})
Requires:       %{gtk2_real_package} = %{gtk2_version}
Requires:       gtk2-metatheme-adwaita
Provides:       gtk2-branding = %{gtk2_version}
Conflicts:      gtk2-branding
Supplements:    packageand(gtk2:branding-%{branding_name})
BuildArch:      noarch

%description
GTK+ is a multi-platform toolkit for creating graphical user interfaces.
Offering a complete set of widgets, GTK+ is suitable for projects
ranging from small one-off projects to complete application suites.

This package provides the %{branding_name} theme configuration for
widgets and icon themes.

%prep
%setup -q -T -c %{name}-%{version}
cp -a %{S:0} gtkrc
cp -a %{S:1} COPYING

%build

%install
install -d %{buildroot}%{_sysconfdir}/gtk-2.0
install -m0644 gtkrc %{buildroot}%{_sysconfdir}/gtk-2.0/

%clean
rm -rf %{buildroot}

%files
%defattr (-, root, root)
%doc COPYING
%config %{_sysconfdir}/gtk-2.0/gtkrc

%changelog
* Thu Mar 14 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Ensure flavor has a value, at least %%nil.
- ExclusiveArch: %%nil is invalid: give it a value (do-not-build).
* Fri Apr  6 2018 fcrozat@suse.com
- Build package for SLE and openSUSE using multibuild.
* Wed May  4 2016 zaitor@opensuse.org
- Update gtk2-branding-gtkrc to have Adwaita as
  gtk-icon-theme-name and hicolor as gtk-fallback-icon-theme
  values.
* Mon Oct 12 2015 zaitor@opensuse.org
- Bump version to 42.1, to prepare for next version of openSUSE.
* Tue Jul 15 2014 dimstar@opensuse.org
- Do not require gnome-icon-theme: GTK2 actually never depended
  on this icon theme; GTK2 always used theme based icons, without
  any fallback to gnome theme iconsets.
- Bump version to 13.2.
* Sun Sep 22 2013 dimstar@opensuse.org
- Run pre_checkin.sh to actually have the version propagated to
  the used .spec files.
* Sun Sep  8 2013 zaitor@opensuse.org
- Bump version to 13.1, to prepare for next version of openSUSE.
* Wed May 23 2012 vuntz@opensuse.org
- Bump version to 12.2, to prepare for next version of openSUSE.
* Thu Oct 13 2011 vuntz@opensuse.org
- Remove %%{release} from the gtk2 versioned Requires, to not have
  to rebuild this package each time gtk2 rebuilds to keep it
  installable.
* Wed Jul  6 2011 vuntz@opensuse.org
- Bump version to 12.1.
- Change default theme to use Adwaita engine and gnome icon theme,
  as we do not have any other good theme for GNOME 3 right now:
  + Update gtk2-branding-gtkrc accordingly.
  + Change gtk2-metatheme-sonar Requires to gtk3-metatheme-adwaita.
  + Change sonar-icon-theme Requires to gnome-icon-theme.
- Change gtk2-devel BuildRequires to gtk2, since this is enough.
- Add a Requires for the package providing gtk2, since the branding
  package is useless without it.
- Update summary and description.
* Tue Nov  2 2010 coolo@novell.com
- remove the changes.in as it makes it complicated to use osc vc
* Tue Nov  2 2010 coolo@novell.com
- do not provide "gtk2", "not" and "installed"
* Fri Oct  8 2010 vuntz@opensuse.org
- Bump version to 11.4.
* Sat Aug  7 2010 vuntz@opensuse.org
- Use Sonar icon theme by default instead of Gilouche. Change
  gtk2-metatheme-gilouche Requires to sonar-icon-theme to reflect
  this.
* Sat Jan 16 2010 vuntz@opensuse.org
- Merge openSUSE and SLED branding packaging, and generate the
  packages from the same sources.
- Change version to 11.3.
- Rename gtk2-branding-openSUSE-COPYING to
  gtk2-branding-COPYING and gtk2-branding-openSUSE-gtkrc to
  gtk2-branding-gtkrc.
- Make sure to provide the right version of gtk2-branding, based on
  the version of the gtk2 package.
* Sun May 24 2009 vuntz@novell.com
- Replace gtk2-theme-openSUSE with gtk2-metatheme-gilouche.
* Tue May 19 2009 vuntz@novell.com
- Change default GTK+ theme to Sonar.
- Add Requires on gtk2-metatheme-sonar.
- Add missing build section.
- Bump version to 11.2.
- Fix order of supplements to remove rpmlint warning.
* Tue Nov  4 2008 vuntz@novell.com
- Bump version to 11.1. Part of bnc#440849.
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881).
* Fri Jun  6 2008 sbrabec@suse.cz
- Bump to correct version (bnc#372091#c6).
* Thu May 29 2008 sbrabec@suse.cz
- Use Gilouche theme as default instead of Tango (bnc#391865).
* Wed May 14 2008 dmueller@suse.de
- add missing provides
* Mon Apr 14 2008 sbrabec@suse.cz
- Use packageand form of branding supplement.
* Wed Apr  9 2008 sbrabec@suse.cz
- Added COPYING file (bnc#368603).
* Mon Apr  7 2008 sbrabec@suse.cz
- Reflect renaming of gtk2-theme-openSUSE package.
* Fri Mar  7 2008 sbrabec@suse.cz
- Split gtk2 default branding definition out from gtk2 as a
  separate package.
